==> react-s-alert-1.3.4.tgz: react-s-alert/README.md <==
# Installation
> `npm install --save @types/react-s-alert`

# Summary
This package contains type definitions for react-s-alert (https://github.com/juliancwirko/react-s-alert).

# Details
Files were exported from https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/react-s-alert.
## [index.d.ts](https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/react-s-alert/index.d.ts)
````ts
// Type definitions for react-s-alert 1.3
// Project: https://github.com/juliancwirko/react-s-alert
// Definitions by: mitsuruog <https://github.com/mitsuruog>
// Definitions: https://github.com/DefinitelyTyped/DefinitelyTyped
// TypeScript Version: 2.8

import * as React from "react";

declare class SAlert extends React.Component<SAlert.SAlertProps> {}

declare namespace SAlert {
    interface SAlertConfigProps {
        position?: string | undefined;
        offset?: number | undefined;
        stack?: boolean | SAlertStackProps | undefined;
        effect?: string | undefined;
        beep?: string | boolean | SAlertBeepProps | undefined;
        timeout?: string | number | undefined;
        html?: boolean | undefined;
        onClose?: (() => void) | undefined;
        onShow?: (() => void) | undefined;
        customFields?: object | undefined;
        contentTemplate?: ((...args: any[]) => any) | undefined;
    }

    interface SAlertProps extends SAlertConfigProps {
        message?: string | undefined;
    }

    interface SAlertStackProps {
        limit?: number | undefined;
        spacing?: number | undefined;
    }

    interface SAlertBeepProps {
        info?: string | undefined;
        error?: string | undefined;
        warning?: string | undefined;
        success?: string | undefined;
    }

    function info(msg?: string, data?: SAlertConfigProps): number;

    function error(msg?: string, data?: SAlertConfigProps): number;

    function warning(msg?: string, data?: SAlertConfigProps): number;

    function success(msg?: string, data?: SAlertConfigProps): number;

    function close(id: number): void;

    function closeAll(): void;
}

export default SAlert;

````

### Additional Details
 * Last updated: Wed, 27 Sep 2023 07:12:04 GMT
 * Dependencies: [@types/react](https://npmjs.com/package/@types/react)
 * Global values: none

# Credits
These definitions were written by [mitsuruog](https://github.com/mitsuruog).

==> react-s-alert-1.3.5.tgz: react-s-alert/README.md <==
# Installation
> `npm install --save @types/react-s-alert`

# Summary
This package contains type definitions for react-s-alert (https://github.com/juliancwirko/react-s-alert).

# Details
Files were exported from https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/react-s-alert.
## [index.d.ts](https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/react-s-alert/index.d.ts)
````ts
import * as React from "react";

declare class SAlert extends React.Component<SAlert.SAlertProps> {}

declare namespace SAlert {
    interface SAlertConfigProps {
        position?: string | undefined;
        offset?: number | undefined;
        stack?: boolean | SAlertStackProps | undefined;
        effect?: string | undefined;
        beep?: string | boolean | SAlertBeepProps | undefined;
        timeout?: string | number | undefined;
        html?: boolean | undefined;
        onClose?: (() => void) | undefined;
        onShow?: (() => void) | undefined;
        customFields?: object | undefined;
        contentTemplate?: ((...args: any[]) => any) | undefined;
    }

    interface SAlertProps extends SAlertConfigProps {
        message?: string | undefined;
    }

    interface SAlertStackProps {
        limit?: number | undefined;
        spacing?: number | undefined;
    }

    interface SAlertBeepProps {
        info?: string | undefined;
        error?: string | undefined;
        warning?: string | undefined;
        success?: string | undefined;
    }

    function info(msg?: string, data?: SAlertConfigProps): number;

    function error(msg?: string, data?: SAlertConfigProps): number;

    function warning(msg?: string, data?: SAlertConfigProps): number;

    function success(msg?: string, data?: SAlertConfigProps): number;

    function close(id: number): void;

    function closeAll(): void;
}

export default SAlert;

````

### Additional Details
 * Last updated: Wed, 18 Oct 2023 11:45:06 GMT
 * Dependencies: [@types/react](https://npmjs.com/package/@types/react)

# Credits
These definitions were written by [mitsuruog](https://github.com/mitsuruog).
